# Settings

### Do you want to connect to a remote Specter?

No, run Specter locally Yes, I run Specter remotely
Remote Specter URL
HTTP Basic Authentication
Username
Password
Connect over Tor
Proxy URL
Advanced ▶

### Specter daemon configurations

Specterd Version
Re-download from GitHub
Specterd File Hash
Specterd CLI args (--tor). Use an equal sign to specify values (--port=25441)

### Use a custom specterd file

Choose file

You can download the specterd file from the github releases page: https://github.com/cryptoadvance/specter-desktop/releases